# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo
from .chat_settings_param import ChatSettingsParam

__all__ = [
    "TaskCreateParams",
    "Main",
    "MainEvaluateStep",
    "MainToolCallStep",
    "MainPromptStepInput",
    "MainPromptStepInputPromptUnionMember0",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainPromptStepInputPromptUnionMember0ToolCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainPromptStepInputToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoice",
    "MainPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainPromptStepInputToolsUnionMember1",
    "MainPromptStepInputToolsUnionMember1ToolRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRef",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainGetStep",
    "MainSetStep",
    "MainLogStep",
    "MainYieldStep",
    "MainReturnStep",
    "MainSleepStep",
    "MainSleepStepSleep",
    "MainErrorWorkflowStep",
    "MainWaitForInputStep",
    "MainWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInput",
    "MainIfElseWorkflowStepInputThen",
    "MainIfElseWorkflowStepInputThenEvaluateStep",
    "MainIfElseWorkflowStepInputThenToolCallStep",
    "MainIfElseWorkflowStepInputThenPromptStepInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputThenGetStep",
    "MainIfElseWorkflowStepInputThenSetStep",
    "MainIfElseWorkflowStepInputThenLogStep",
    "MainIfElseWorkflowStepInputThenYieldStep",
    "MainIfElseWorkflowStepInputThenReturnStep",
    "MainIfElseWorkflowStepInputThenSleepStep",
    "MainIfElseWorkflowStepInputThenSleepStepSleep",
    "MainIfElseWorkflowStepInputThenErrorWorkflowStep",
    "MainIfElseWorkflowStepInputThenWaitForInputStep",
    "MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepInputElse",
    "MainIfElseWorkflowStepInputElseEvaluateStep",
    "MainIfElseWorkflowStepInputElseToolCallStep",
    "MainIfElseWorkflowStepInputElsePromptStepInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainIfElseWorkflowStepInputElseGetStep",
    "MainIfElseWorkflowStepInputElseSetStep",
    "MainIfElseWorkflowStepInputElseLogStep",
    "MainIfElseWorkflowStepInputElseYieldStep",
    "MainIfElseWorkflowStepInputElseReturnStep",
    "MainIfElseWorkflowStepInputElseSleepStep",
    "MainIfElseWorkflowStepInputElseSleepStepSleep",
    "MainIfElseWorkflowStepInputElseErrorWorkflowStep",
    "MainIfElseWorkflowStepInputElseWaitForInputStep",
    "MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput",
    "MainSwitchStepInput",
    "MainSwitchStepInputSwitch",
    "MainSwitchStepInputSwitchThen",
    "MainSwitchStepInputSwitchThenEvaluateStep",
    "MainSwitchStepInputSwitchThenToolCallStep",
    "MainSwitchStepInputSwitchThenPromptStepInput",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice",
    "MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainSwitchStepInputSwitchThenGetStep",
    "MainSwitchStepInputSwitchThenSetStep",
    "MainSwitchStepInputSwitchThenLogStep",
    "MainSwitchStepInputSwitchThenYieldStep",
    "MainSwitchStepInputSwitchThenReturnStep",
    "MainSwitchStepInputSwitchThenSleepStep",
    "MainSwitchStepInputSwitchThenSleepStepSleep",
    "MainSwitchStepInputSwitchThenErrorWorkflowStep",
    "MainSwitchStepInputSwitchThenWaitForInputStep",
    "MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput",
    "MainForeachStepInput",
    "MainForeachStepInputForeach",
    "MainForeachStepInputForeachDo",
    "MainForeachStepInputForeachDoWaitForInputStep",
    "MainForeachStepInputForeachDoWaitForInputStepWaitForInput",
    "MainForeachStepInputForeachDoEvaluateStep",
    "MainForeachStepInputForeachDoToolCallStep",
    "MainForeachStepInputForeachDoPromptStepInput",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice",
    "MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainForeachStepInputForeachDoGetStep",
    "MainForeachStepInputForeachDoSetStep",
    "MainForeachStepInputForeachDoLogStep",
    "MainForeachStepInputForeachDoYieldStep",
    "MainParallelStepInput",
    "MainParallelStepInputParallel",
    "MainParallelStepInputParallelEvaluateStep",
    "MainParallelStepInputParallelToolCallStep",
    "MainParallelStepInputParallelPromptStepInput",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice",
    "MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainParallelStepInputParallelGetStep",
    "MainParallelStepInputParallelSetStep",
    "MainParallelStepInputParallelLogStep",
    "MainParallelStepInputParallelYieldStep",
    "MainMainInput",
    "MainMainInputMap",
    "MainMainInputMapEvaluateStep",
    "MainMainInputMapToolCallStep",
    "MainMainInputMapPromptStepInput",
    "MainMainInputMapPromptStepInputPromptUnionMember0",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022",
    "MainMainInputMapPromptStepInputToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoice",
    "MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID",
    "MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem",
    "MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022",
    "MainMainInputMapGetStep",
    "MainMainInputMapSetStep",
    "MainMainInputMapLogStep",
    "MainMainInputMapYieldStep",
    "Tool",
    "ToolAPICall",
    "ToolBash20241022",
    "ToolComputer20241022",
    "ToolFunction",
    "ToolIntegration",
    "ToolIntegrationDummyIntegrationDef",
    "ToolIntegrationBraveIntegrationDef",
    "ToolIntegrationBraveIntegrationDefArguments",
    "ToolIntegrationBraveIntegrationDefSetup",
    "ToolIntegrationEmailIntegrationDef",
    "ToolIntegrationEmailIntegrationDefArguments",
    "ToolIntegrationEmailIntegrationDefSetup",
    "ToolIntegrationSpiderIntegrationDefInput",
    "ToolIntegrationSpiderIntegrationDefInputArguments",
    "ToolIntegrationSpiderIntegrationDefInputSetup",
    "ToolIntegrationWikipediaIntegrationDef",
    "ToolIntegrationWikipediaIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDef",
    "ToolIntegrationWeatherIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDefSetup",
    "ToolIntegrationBrowserbaseContextIntegrationDef",
    "ToolIntegrationBrowserbaseContextIntegrationDefArguments",
    "ToolIntegrationBrowserbaseContextIntegrationDefSetup",
    "ToolIntegrationBrowserbaseExtensionIntegrationDef",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDef",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDef",
    "ToolIntegrationRemoteBrowserIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDef",
    "ToolIntegrationLlamaParseIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDefSetup",
    "ToolIntegrationFfmpegIntegrationDef",
    "ToolIntegrationFfmpegIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDef",
    "ToolIntegrationCloudinaryUploadIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDefSetup",
    "ToolIntegrationCloudinaryEditIntegrationDef",
    "ToolIntegrationCloudinaryEditIntegrationDefArguments",
    "ToolIntegrationCloudinaryEditIntegrationDefSetup",
    "ToolIntegrationArxivIntegrationDef",
    "ToolIntegrationArxivIntegrationDefArguments",
    "ToolSystem",
    "ToolTextEditor20241022",
]


class TaskCreateParams(TypedDict, total=False):
    main: Required[Iterable[Main]]

    name: Required[str]

    description: str

    inherit_tools: bool

    input_schema: Optional[object]

    metadata: Optional[object]

    tools: Iterable[Tool]


class MainEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(TypedDict, total=False):
    image_url: Required[
        MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0],
            Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022]

    type: Literal["function"]


class MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainPromptStepInputPromptUnionMember0(_MainPromptStepInputPromptUnionMember0ReservedKeywords, total=False):
    content: Required[Union[List[str], Iterable[MainPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainPromptStepInputPromptUnionMember0ToolCall]]


class MainPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainPromptStepInputToolChoiceNamedToolChoiceFunction]


MainPromptStepInputToolChoice: TypeAlias = Union[Literal["auto", "none"], MainPromptStepInputToolChoiceNamedToolChoice]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(TypedDict, total=False):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall]
    """API call definition"""

    bash_20241022: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022]

    computer_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction]
    """Function definition"""

    integration: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration]
    """Brave integration definition"""

    system: Optional[MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem]
    """System definition"""

    text_editor_20241022: Optional[
        MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainPromptStepInputToolsUnionMember1ToolRef,
    MainPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainReturnStepReservedKeywords = TypedDict(
    "_MainReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainReturnStep(_MainReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSleepStep(TypedDict, total=False):
    sleep: Required[MainSleepStepSleep]

    label: Optional[str]


class MainErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainWaitForInputStepWaitForInput]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputThenPromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainIfElseWorkflowStepInputThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputThenReturnStep(
    _MainIfElseWorkflowStepInputThenReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputThenSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputThenSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputThen: TypeAlias = Union[
    MainIfElseWorkflowStepInputThenEvaluateStep,
    MainIfElseWorkflowStepInputThenToolCallStep,
    MainIfElseWorkflowStepInputThenPromptStepInput,
    MainIfElseWorkflowStepInputThenGetStep,
    MainIfElseWorkflowStepInputThenSetStep,
    MainIfElseWorkflowStepInputThenLogStep,
    MainIfElseWorkflowStepInputThenYieldStep,
    MainIfElseWorkflowStepInputThenReturnStep,
    MainIfElseWorkflowStepInputThenSleepStep,
    MainIfElseWorkflowStepInputThenErrorWorkflowStep,
    MainIfElseWorkflowStepInputThenWaitForInputStep,
]


class MainIfElseWorkflowStepInputElseEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(
    TypedDict, total=False
):
    function: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction
    ]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0(
    _MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0ToolCall]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoiceFunction]


MainIfElseWorkflowStepInputElsePromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepInputElsePromptStepInputToolChoiceNamedToolChoice
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainIfElseWorkflowStepInputElsePromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainIfElseWorkflowStepInputElsePromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainIfElseWorkflowStepInputElsePromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainIfElseWorkflowStepInputElsePromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainIfElseWorkflowStepInputElseGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputElseReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainIfElseWorkflowStepInputElseReturnStep(
    _MainIfElseWorkflowStepInputElseReturnStepReservedKeywords, total=False
):
    label: Optional[str]


class MainIfElseWorkflowStepInputElseSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainIfElseWorkflowStepInputElseSleepStep(TypedDict, total=False):
    sleep: Required[MainIfElseWorkflowStepInputElseSleepStepSleep]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainIfElseWorkflowStepInputElseWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainIfElseWorkflowStepInputElseWaitForInputStepWaitForInput]

    label: Optional[str]


MainIfElseWorkflowStepInputElse: TypeAlias = Union[
    MainIfElseWorkflowStepInputElseEvaluateStep,
    MainIfElseWorkflowStepInputElseToolCallStep,
    MainIfElseWorkflowStepInputElsePromptStepInput,
    MainIfElseWorkflowStepInputElseGetStep,
    MainIfElseWorkflowStepInputElseSetStep,
    MainIfElseWorkflowStepInputElseLogStep,
    MainIfElseWorkflowStepInputElseYieldStep,
    MainIfElseWorkflowStepInputElseReturnStep,
    MainIfElseWorkflowStepInputElseSleepStep,
    MainIfElseWorkflowStepInputElseErrorWorkflowStep,
    MainIfElseWorkflowStepInputElseWaitForInputStep,
]

_MainIfElseWorkflowStepInputReservedKeywords = TypedDict(
    "_MainIfElseWorkflowStepInputReservedKeywords",
    {
        "if": str,
        "else": Optional[MainIfElseWorkflowStepInputElse],
    },
    total=False,
)


class MainIfElseWorkflowStepInput(_MainIfElseWorkflowStepInputReservedKeywords, total=False):
    then: Required[MainIfElseWorkflowStepInputThen]

    label: Optional[str]


class MainSwitchStepInputSwitchThenEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0(
    _MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0ToolCall]]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoiceFunction]


MainSwitchStepInputSwitchThenPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainSwitchStepInputSwitchThenPromptStepInputToolChoiceNamedToolChoice
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1ToolRef,
    MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainSwitchStepInputSwitchThenPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainSwitchStepInputSwitchThenPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainSwitchStepInputSwitchThenPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainSwitchStepInputSwitchThenPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainSwitchStepInputSwitchThenGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainSwitchStepInputSwitchThenLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


_MainSwitchStepInputSwitchThenReturnStepReservedKeywords = TypedDict(
    "_MainSwitchStepInputSwitchThenReturnStepReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class MainSwitchStepInputSwitchThenReturnStep(_MainSwitchStepInputSwitchThenReturnStepReservedKeywords, total=False):
    label: Optional[str]


class MainSwitchStepInputSwitchThenSleepStepSleep(TypedDict, total=False):
    days: int

    hours: int

    minutes: int

    seconds: int


class MainSwitchStepInputSwitchThenSleepStep(TypedDict, total=False):
    sleep: Required[MainSwitchStepInputSwitchThenSleepStepSleep]

    label: Optional[str]


class MainSwitchStepInputSwitchThenErrorWorkflowStep(TypedDict, total=False):
    error: Required[str]

    label: Optional[str]


class MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainSwitchStepInputSwitchThenWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainSwitchStepInputSwitchThenWaitForInputStepWaitForInput]

    label: Optional[str]


MainSwitchStepInputSwitchThen: TypeAlias = Union[
    MainSwitchStepInputSwitchThenEvaluateStep,
    MainSwitchStepInputSwitchThenToolCallStep,
    MainSwitchStepInputSwitchThenPromptStepInput,
    MainSwitchStepInputSwitchThenGetStep,
    MainSwitchStepInputSwitchThenSetStep,
    MainSwitchStepInputSwitchThenLogStep,
    MainSwitchStepInputSwitchThenYieldStep,
    MainSwitchStepInputSwitchThenReturnStep,
    MainSwitchStepInputSwitchThenSleepStep,
    MainSwitchStepInputSwitchThenErrorWorkflowStep,
    MainSwitchStepInputSwitchThenWaitForInputStep,
]


class MainSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[MainSwitchStepInputSwitchThen]


class MainSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[MainSwitchStepInputSwitch]]

    label: Optional[str]


class MainForeachStepInputForeachDoWaitForInputStepWaitForInput(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]


class MainForeachStepInputForeachDoWaitForInputStep(TypedDict, total=False):
    wait_for_input: Required[MainForeachStepInputForeachDoWaitForInputStepWaitForInput]

    label: Optional[str]


class MainForeachStepInputForeachDoEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainForeachStepInputForeachDoToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0(
    _MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0ToolCall]]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoiceFunction]


MainForeachStepInputForeachDoPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainForeachStepInputForeachDoPromptStepInputToolChoiceNamedToolChoice
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1ToolRef,
    MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainForeachStepInputForeachDoPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainForeachStepInputForeachDoPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainForeachStepInputForeachDoPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainForeachStepInputForeachDoPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainForeachStepInputForeachDoGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainForeachStepInputForeachDoLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainForeachStepInputForeachDoYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainForeachStepInputForeachDo: TypeAlias = Union[
    MainForeachStepInputForeachDoWaitForInputStep,
    MainForeachStepInputForeachDoEvaluateStep,
    MainForeachStepInputForeachDoToolCallStep,
    MainForeachStepInputForeachDoPromptStepInput,
    MainForeachStepInputForeachDoGetStep,
    MainForeachStepInputForeachDoSetStep,
    MainForeachStepInputForeachDoLogStep,
    MainForeachStepInputForeachDoYieldStep,
]

_MainForeachStepInputForeachReservedKeywords = TypedDict(
    "_MainForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class MainForeachStepInputForeach(_MainForeachStepInputForeachReservedKeywords, total=False):
    do: Required[MainForeachStepInputForeachDo]


class MainForeachStepInput(TypedDict, total=False):
    foreach: Required[MainForeachStepInputForeach]

    label: Optional[str]


class MainParallelStepInputParallelEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainParallelStepInputParallelToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(
    TypedDict, total=False
):
    content: Required[
        Union[
            Iterable[
                MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    TypedDict, total=False
):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    TypedDict, total=False
):
    command: Optional[str]

    restart: bool


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputPromptUnionMember0(
    _MainParallelStepInputParallelPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[
            List[str],
            Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ContentUnionMember1],
            str,
            None,
        ]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0ToolCall]]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoiceFunction]


MainParallelStepInputParallelPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainParallelStepInputParallelPromptStepInputToolChoiceNamedToolChoice
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem
    ]
    """System definition"""

    text_editor_20241022: Optional[
        MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainParallelStepInputParallelPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1ToolRef,
    MainParallelStepInputParallelPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainParallelStepInputParallelPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainParallelStepInputParallelPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainParallelStepInputParallelPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainParallelStepInputParallelPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainParallelStepInputParallelGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainParallelStepInputParallelLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainParallelStepInputParallelYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainParallelStepInputParallel: TypeAlias = Union[
    MainParallelStepInputParallelEvaluateStep,
    MainParallelStepInputParallelToolCallStep,
    MainParallelStepInputParallelPromptStepInput,
    MainParallelStepInputParallelGetStep,
    MainParallelStepInputParallelSetStep,
    MainParallelStepInputParallelLogStep,
    MainParallelStepInputParallelYieldStep,
]


class MainParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[MainParallelStepInputParallel]]

    label: Optional[str]


class MainMainInputMapEvaluateStep(TypedDict, total=False):
    evaluate: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]

    label: Optional[str]


class MainMainInputMapToolCallStep(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[
        Dict[
            str,
            Union[
                Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                str,
            ],
        ],
        Iterable[
            Dict[
                str,
                Union[
                    Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
                    Iterable[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]],
                    str,
                ],
            ]
        ],
        Literal["_"],
    ]

    label: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    TypedDict, total=False
):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    TypedDict, total=False
):
    image_url: Required[
        MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    ]
    """The image URL"""

    type: Literal["image_url"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(
    TypedDict, total=False
):
    text: Required[str]

    type: Literal["text"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(
    TypedDict, total=False
):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(
    TypedDict, total=False
):
    source: Required[
        MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source
    ]

    type: Literal["image"]


class MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[
                MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0
            ],
            Iterable[
                MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1
            ],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1Content,
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1ContentModel1Input,
]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    TypedDict, total=False
):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallFunction]

    api_call: Optional[object]

    bash_20241022: Optional[MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ]

    integration: Optional[object]

    system: Optional[object]

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ]

    type: Literal["function"]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


MainMainInputMapPromptStepInputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenFunctionCall,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenComputer20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainMainInputMapPromptStepInputPromptUnionMember0ToolCallChosenBash20241022,
]

_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MainMainInputMapPromptStepInputPromptUnionMember0(
    _MainMainInputMapPromptStepInputPromptUnionMember0ReservedKeywords, total=False
):
    content: Required[
        Union[List[str], Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ContentUnionMember1], str, None]
    ]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0ToolCall]]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class MainMainInputMapPromptStepInputToolChoiceNamedToolChoice(TypedDict, total=False):
    function: Optional[MainMainInputMapPromptStepInputToolChoiceNamedToolChoiceFunction]


MainMainInputMapPromptStepInputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainMainInputMapPromptStepInputToolChoiceNamedToolChoice
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByID,
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainMainInputMapPromptStepInputToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[MainMainInputMapPromptStepInputToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(
    TypedDict, total=False
):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["bash_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022(
    TypedDict, total=False
):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction(
    TypedDict, total=False
):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefArguments
    ]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDefSetup
    ]
    """Integration definition for Brave Search"""


_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments(
    _MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArgumentsReservedKeywords,
    total=False,
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup(
    TypedDict, total=False
):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefArguments
    ]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDefSetup
    ]
    """Setup parameters for Email integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments(
    TypedDict, total=False
):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup(
    TypedDict, total=False
):
    spider_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputArguments
    ]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInputSetup
    ]
    """Setup parameters for Spider integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    load_max_docs: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDefArguments
    ]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments(
    TypedDict, total=False
):
    location: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup(
    TypedDict, total=False
):
    openweathermap_api_key: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefArguments
    ]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDefSetup
    ]
    """Integration definition for Weather"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments(
    TypedDict, total=False
):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefArguments
    ]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    TypedDict, total=False
):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    TypedDict, total=False
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    TypedDict, total=False
):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(
    TypedDict, total=False
):
    id: Required[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(
    TypedDict, total=False
):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments
    ]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup
    ]
    """The setup parameters for the browserbase integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup(
    TypedDict, total=False
):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments(
    TypedDict, total=False
):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef(
    TypedDict, total=False
):
    setup: Required[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefSetup
    ]
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDefArguments
    ]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup(
    TypedDict, total=False
):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefArguments
    ]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDefSetup
    ]
    """Setup parameters for LlamaParse integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments(
    TypedDict, total=False
):
    cmd: Required[str]

    file: Optional[str]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDefArguments
    ]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments(
    TypedDict, total=False
):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefArguments
    ]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments(
    TypedDict, total=False
):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup(
    TypedDict, total=False
):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefArguments
    ]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDefSetup
    ]
    """Setup parameters for Cloudinary integration"""


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments(
    TypedDict, total=False
):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef(
    TypedDict, total=False
):
    arguments: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDefArguments
    ]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationDummyIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBraveIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationEmailIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationSpiderIntegrationDefInput,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWikipediaIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationWeatherIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseContextIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseExtensionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationRemoteBrowserIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationLlamaParseIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationFfmpegIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryUploadIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationCloudinaryEditIntegrationDef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegrationArxivIntegrationDef,
]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem(
    TypedDict, total=False
):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022(
    TypedDict, total=False
):
    name: str

    type: Literal["text_editor_20241022"]


class MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(
    TypedDict, total=False
):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall
    ]
    """API call definition"""

    bash_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputBash20241022
    ]

    computer_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputComputer20241022
    ]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputFunction
    ]
    """Function definition"""

    integration: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration
    ]
    """Brave integration definition"""

    system: Optional[MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputSystem]
    """System definition"""

    text_editor_20241022: Optional[
        MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputTextEditor20241022
    ]


MainMainInputMapPromptStepInputToolsUnionMember1: TypeAlias = Union[
    MainMainInputMapPromptStepInputToolsUnionMember1ToolRef,
    MainMainInputMapPromptStepInputToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput,
]


class MainMainInputMapPromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[MainMainInputMapPromptStepInputPromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[ChatSettingsParam]

    tool_choice: Optional[MainMainInputMapPromptStepInputToolChoice]

    tools: Union[Literal["all"], Iterable[MainMainInputMapPromptStepInputToolsUnionMember1]]

    unwrap: bool


class MainMainInputMapGetStep(TypedDict, total=False):
    get: Required[str]

    label: Optional[str]


class MainMainInputMapSetStep(TypedDict, total=False):
    set: Required[Dict[str, str]]

    label: Optional[str]


class MainMainInputMapLogStep(TypedDict, total=False):
    log: Required[str]

    label: Optional[str]


class MainMainInputMapYieldStep(TypedDict, total=False):
    workflow: Required[str]

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]], Literal["_"]]

    label: Optional[str]


MainMainInputMap: TypeAlias = Union[
    MainMainInputMapEvaluateStep,
    MainMainInputMapToolCallStep,
    MainMainInputMapPromptStepInput,
    MainMainInputMapGetStep,
    MainMainInputMapSetStep,
    MainMainInputMapLogStep,
    MainMainInputMapYieldStep,
]


class MainMainInput(TypedDict, total=False):
    map: Required[MainMainInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


Main: TypeAlias = Union[
    MainEvaluateStep,
    MainToolCallStep,
    MainPromptStepInput,
    MainGetStep,
    MainSetStep,
    MainLogStep,
    MainYieldStep,
    MainReturnStep,
    MainSleepStep,
    MainErrorWorkflowStep,
    MainWaitForInputStep,
    MainIfElseWorkflowStepInput,
    MainSwitchStepInput,
    MainForeachStepInput,
    MainParallelStepInput,
    MainMainInput,
]


class ToolAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    json: Optional[object]

    params: Union[str, object, None]

    schema: Optional[object]

    timeout: Optional[int]


class ToolBash20241022(TypedDict, total=False):
    name: str

    type: Literal["bash_20241022"]


class ToolComputer20241022(TypedDict, total=False):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]


class ToolFunction(TypedDict, total=False):
    description: Optional[object]

    name: Optional[object]

    parameters: Optional[object]


class ToolIntegrationDummyIntegrationDef(TypedDict, total=False):
    arguments: Optional[object]

    method: Optional[str]

    provider: Literal["dummy"]

    setup: Optional[object]


class ToolIntegrationBraveIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]


class ToolIntegrationBraveIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]


class ToolIntegrationBraveIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBraveIntegrationDefArguments]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[ToolIntegrationBraveIntegrationDefSetup]
    """Integration definition for Brave Search"""


_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords = TypedDict(
    "_ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class ToolIntegrationEmailIntegrationDefArguments(
    _ToolIntegrationEmailIntegrationDefArgumentsReservedKeywords, total=False
):
    body: Required[str]

    subject: Required[str]

    to: Required[str]


class ToolIntegrationEmailIntegrationDefSetup(TypedDict, total=False):
    host: Required[str]

    password: Required[str]

    port: Required[int]

    user: Required[str]


class ToolIntegrationEmailIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationEmailIntegrationDefArguments]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[ToolIntegrationEmailIntegrationDefSetup]
    """Setup parameters for Email integration"""


class ToolIntegrationSpiderIntegrationDefInputArguments(TypedDict, total=False):
    url: Required[str]

    mode: Literal["scrape"]

    params: Optional[object]


class ToolIntegrationSpiderIntegrationDefInputSetup(TypedDict, total=False):
    spider_api_key: Required[str]


class ToolIntegrationSpiderIntegrationDefInput(TypedDict, total=False):
    arguments: Optional[ToolIntegrationSpiderIntegrationDefInputArguments]
    """Arguments for Spider integration"""

    method: Optional[str]

    provider: Literal["spider"]

    setup: Optional[ToolIntegrationSpiderIntegrationDefInputSetup]
    """Setup parameters for Spider integration"""


class ToolIntegrationWikipediaIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]

    load_max_docs: int


class ToolIntegrationWikipediaIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWikipediaIntegrationDefArguments]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: Optional[object]


class ToolIntegrationWeatherIntegrationDefArguments(TypedDict, total=False):
    location: Required[str]


class ToolIntegrationWeatherIntegrationDefSetup(TypedDict, total=False):
    openweathermap_api_key: Required[str]


class ToolIntegrationWeatherIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationWeatherIntegrationDefArguments]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[ToolIntegrationWeatherIntegrationDefSetup]
    """Integration definition for Weather"""


class ToolIntegrationBrowserbaseContextIntegrationDefArguments(TypedDict, total=False):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]


class ToolIntegrationBrowserbaseContextIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseContextIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseContextIntegrationDefArguments]

    method: Literal["create_context"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseContextIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseExtensionIntegrationDefArguments(TypedDict, total=False):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseExtensionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefArguments]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments(TypedDict, total=False):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]


class ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseListSessionsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments(TypedDict, total=False):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCreateSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments]

    method: Literal["create_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments]

    method: Literal["get_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments]

    method: Literal["complete_session"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments]

    method: Literal["get_live_urls"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments(TypedDict, total=False):
    id: Required[str]


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]


class ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefArguments]

    method: Literal["get_connect_url"]

    provider: Literal["browserbase"]

    setup: Optional[ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDefSetup]
    """The setup parameters for the browserbase integration"""


class ToolIntegrationRemoteBrowserIntegrationDefSetup(TypedDict, total=False):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]


class ToolIntegrationRemoteBrowserIntegrationDefArguments(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]


class ToolIntegrationRemoteBrowserIntegrationDef(TypedDict, total=False):
    setup: Required[ToolIntegrationRemoteBrowserIntegrationDefSetup]
    """The setup parameters for the remote browser"""

    arguments: Optional[ToolIntegrationRemoteBrowserIntegrationDefArguments]
    """The arguments for the remote browser"""

    method: Literal["perform_action"]

    provider: Literal["remote_browser"]


class ToolIntegrationLlamaParseIntegrationDefArguments(TypedDict, total=False):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]


class ToolIntegrationLlamaParseIntegrationDefSetup(TypedDict, total=False):
    llamaparse_api_key: Required[str]

    params: Optional[object]


class ToolIntegrationLlamaParseIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationLlamaParseIntegrationDefArguments]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[ToolIntegrationLlamaParseIntegrationDefSetup]
    """Setup parameters for LlamaParse integration"""


class ToolIntegrationFfmpegIntegrationDefArguments(TypedDict, total=False):
    cmd: Required[str]

    file: Optional[str]


class ToolIntegrationFfmpegIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationFfmpegIntegrationDefArguments]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: Optional[object]


class ToolIntegrationCloudinaryUploadIntegrationDefArguments(TypedDict, total=False):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]


class ToolIntegrationCloudinaryUploadIntegrationDefSetup(TypedDict, total=False):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class ToolIntegrationCloudinaryUploadIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationCloudinaryUploadIntegrationDefArguments]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[ToolIntegrationCloudinaryUploadIntegrationDefSetup]
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationCloudinaryEditIntegrationDefArguments(TypedDict, total=False):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool


class ToolIntegrationCloudinaryEditIntegrationDefSetup(TypedDict, total=False):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]


class ToolIntegrationCloudinaryEditIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationCloudinaryEditIntegrationDefArguments]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[ToolIntegrationCloudinaryEditIntegrationDefSetup]
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationArxivIntegrationDefArguments(TypedDict, total=False):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]


class ToolIntegrationArxivIntegrationDef(TypedDict, total=False):
    arguments: Optional[ToolIntegrationArxivIntegrationDefArguments]
    """Arguments for Arxiv Search"""

    method: Optional[str]

    provider: Literal["arxiv"]

    setup: Optional[object]


ToolIntegration: TypeAlias = Union[
    ToolIntegrationDummyIntegrationDef,
    ToolIntegrationBraveIntegrationDef,
    ToolIntegrationEmailIntegrationDef,
    ToolIntegrationSpiderIntegrationDefInput,
    ToolIntegrationWikipediaIntegrationDef,
    ToolIntegrationWeatherIntegrationDef,
    ToolIntegrationBrowserbaseContextIntegrationDef,
    ToolIntegrationBrowserbaseExtensionIntegrationDef,
    ToolIntegrationBrowserbaseListSessionsIntegrationDef,
    ToolIntegrationBrowserbaseCreateSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionIntegrationDef,
    ToolIntegrationBrowserbaseCompleteSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionConnectURLIntegrationDef,
    ToolIntegrationRemoteBrowserIntegrationDef,
    ToolIntegrationLlamaParseIntegrationDef,
    ToolIntegrationFfmpegIntegrationDef,
    ToolIntegrationCloudinaryUploadIntegrationDef,
    ToolIntegrationCloudinaryEditIntegrationDef,
    ToolIntegrationArxivIntegrationDef,
]


class ToolSystem(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]


class ToolTextEditor20241022(TypedDict, total=False):
    name: str

    type: Literal["text_editor_20241022"]


class Tool(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[ToolAPICall]
    """API call definition"""

    bash_20241022: Optional[ToolBash20241022]

    computer_20241022: Optional[ToolComputer20241022]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[ToolFunction]
    """Function definition"""

    integration: Optional[ToolIntegration]
    """Brave integration definition"""

    system: Optional[ToolSystem]
    """System definition"""

    text_editor_20241022: Optional[ToolTextEditor20241022]
